% Aufgabe 2.6.4: Lineare Transformation
%    [dx,dy] = linTransf( w, v, t )
%    w : Drehwinkel im Bogenmaß
%    v : der zu drehende Vektor
%    t : Verschiebungsvektor
function [dx,dy] = linTransf( w, v, t )
    A(1,1) =   cos(w);
    A(1,2) = - sin(w);
    A(2,1) =   sin(w);
    A(2,2) =   cos(w);
    
    d = A * v + t;
    dx = d(1);
    dy = d(2);
end